// ======================================================================
//
// MenuSelector.cpp
// jeff grills
//
// copyright 1997 origin systems inc
//
// ======================================================================

#include "First.h"
#include "MenuSelector.h"

#include "Bitmap.h"
#include "Gl.h"
#include "Iff.h"

// ======================================================================

const Tag TAG_INT                    = TAG3(I,N,T);

// ======================================================================

MenuSelector::MenuSelector(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff)
: MenuElement(parent, maxWidth, maxHeight, NULL)
{
	currentSelector = 0;
	load(iff);
}

// ----------------------------------------------------------------------

MenuSelector::~MenuSelector(void)
{
}

// ----------------------------------------------------------------------

int MenuSelector::getCurrentSelector(void) const
{
	return currentSelector;
}

// ----------------------------------------------------------------------

void MenuSelector::setCurrentSelector(int newSelector)
{
	currentSelector = newSelector;
}

// ----------------------------------------------------------------------

MenuElement *MenuSelector::getCurrentElement(void) const
{
	MenuElement *me;
	int          i;

	i = getCurrentSelector();
	for (me = firstChild; me && i; me = me->getNextSibling(), i--)
		;

	return me;
}

// ----------------------------------------------------------------------

IoResult MenuSelector::update(void)
{
	MenuElement *e;

	if ((e = getCurrentElement()) != NULL)
		return e->update();

	return IoResultPass;
}

// ----------------------------------------------------------------------

IoResult MenuSelector::event(IoEventStruct *event)
{
	int          x, y;
	IoResult     result;
	MenuElement *e;

	// save off the events location
	x = event->mouseX;
	y = event->mouseY;

	// adjust the location to be relative to this box
	event->mouseX -= menuRect.x0;
	event->mouseY -= menuRect.y0;

	if ((e = getCurrentElement()) != NULL)
	{
		result = e->event(event);
		DEBUG_FATAL(IoWinManager::isKill(result), ("MenuCombo::event returned kill"));
	}
	else
		result = IoResultPass;

	// put the location back the way we found it
	event->mouseX = x;
	event->mouseY = y;

	return result;
}

// ----------------------------------------------------------------------

void MenuSelector::menuDraw(int x, int y) const
{
	MenuElement *e;

	if ((e = getCurrentElement()) != NULL)
		e->menuDraw(x + menuRect.x0, y + menuRect.y0);

	if (DFlag(DF_E_MENU_BOXES))
	{
		Gl::setMaterial(MaterialList::red());
		Gl::rect(menuRect.x0+x, menuRect.y0+y, menuRect.x1+x, menuRect.y1+y);
	}
}

// ======================================================================

MenuIntSelector::MenuIntSelector(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff)
: MenuSelector(parent, maxWidth, maxHeight, NULL)
{
	load(iff);
}

// ----------------------------------------------------------------------

MenuIntSelector::~MenuIntSelector(void)
{
	menuResourceInteger = NULL;
}

// ----------------------------------------------------------------------

void MenuIntSelector::load(Iff *iff)
{
	char *name;

	if (iff)
	{
		MenuSelector::load(iff);

		iff->seekChunk(TAG_INT);
		name = iff->read_char(Iff::ReadRest);
		menuResourceInteger = findSharedInteger(name);
		DEBUG_FATAL(!menuResourceInteger, ("MENU_INT_SELECTOR cannot find shared integer '%s'", menuResourceInteger));

		delete [] name;
		iff->exitChunk();
	}
}

// ----------------------------------------------------------------------

int MenuIntSelector::getCurrentSelector(void) const
{
	return menuResourceInteger->getValue();	
}

// ----------------------------------------------------------------------

void MenuIntSelector::setCurrentSelector(int newSelector)
{
	menuResourceInteger->setValue(newSelector);
}

// ======================================================================

